from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Array, String, File, Int, Boolean

Methylpy_Filter_Allc_V0_1_0 = CommandToolBuilder(tool="methylpy_filter_allc", base_command=["methylpy", "filter-allc"], inputs=[ToolInput(tag="in_all_c_files", input_type=Array(t=String(), optional=True), prefix="--allc-files", doc=InputDocumentation(doc="allc files to filter. (default: None)")), ToolInput(tag="in_output_files", input_type=File(optional=True), prefix="--output-files", doc=InputDocumentation(doc="Name of output files. Each output file matches each\nallc file. (default: None)")), ToolInput(tag="in_num_procs", input_type=Int(optional=True), prefix="--num-procs", doc=InputDocumentation(doc="Number of processors you wish to use to parallelize\nthis function (default: 1)")), ToolInput(tag="in_mc_type", input_type=File(optional=True), prefix="--mc-type", doc=InputDocumentation(doc="List of space separated cytosine nucleotide contexts\nfor sites to be included in output file. These\nclassifications may use the wildcards H (indicating\nanything but a G) and N (indicating any nucleotide).\n(default: None)")), ToolInput(tag="in_min_cov", input_type=Int(optional=True), prefix="--min-cov", doc=InputDocumentation(doc="Minimum number of reads that must cover a site for it\nto be included in the output file. (default: 0)")), ToolInput(tag="in_max_cov", input_type=Int(optional=True), prefix="--max-cov", doc=InputDocumentation(doc="Maximum number of reads that must cover a site for it\nto be included in the output file. By default this\ncutoff is not applied. (default: None)")), ToolInput(tag="in_max_mismatch", input_type=File(optional=True), prefix="--max-mismatch", doc=InputDocumentation(doc="Maximum numbers of mismatch basecalls allowed in each\nnucleotide in the sequence context of a site for it to\nbe included in output file. If the sequence context\nhas three nucleotides, an example of this option is '0\n1 2'. It requires no mismatch basecall at the first\nnucleotide, at most one mismatch basecall at the\nsecond nucleotide, and at most two at the third\nnucleotide for a site to be reported. (default: None)")), ToolInput(tag="in_max_mismatch_frac", input_type=File(optional=True), prefix="--max-mismatch-frac", doc=InputDocumentation(doc="Maximum fraction of mismatch basecalls out of\nunambiguous basecalls allowed in each nucleotide in\nthe sequence context of a site for it to be included\nin output file. If the sequence context has three\nnucleotides, an example of this option is '0 0 0.1'.\nIt requires no mismatch basecall at the first and\nsecond nucleotide, and at most 10% mismatches out of\nunambiguous basecalls at the third nucleotide for a\nsite to be reported. (default: None)")), ToolInput(tag="in_compress_output", input_type=Boolean(optional=True), prefix="--compress-output", doc=InputDocumentation(doc="Boolean indicating whether to compress (by gzip) the\nfinal output (default: True)")), ToolInput(tag="in_chrom_s", input_type=Array(t=String(), optional=True), prefix="--chroms", doc=InputDocumentation(doc="Space separated listing of chromosomes to be included\nin the output. By default, data of all chromosomes in\ninput allc file will be included. (default: None)\n"))], outputs=[ToolOutput(tag="out_output_files", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_files", type_hint=File()), doc=OutputDocumentation(doc="Name of output files. Each output file matches each\nallc file. (default: None)")), ToolOutput(tag="out_mc_type", output_type=File(optional=True), selector=InputSelector(input_to_select="in_mc_type", type_hint=File()), doc=OutputDocumentation(doc="List of space separated cytosine nucleotide contexts\nfor sites to be included in output file. These\nclassifications may use the wildcards H (indicating\nanything but a G) and N (indicating any nucleotide).\n(default: None)")), ToolOutput(tag="out_max_mismatch", output_type=File(optional=True), selector=InputSelector(input_to_select="in_max_mismatch", type_hint=File()), doc=OutputDocumentation(doc="Maximum numbers of mismatch basecalls allowed in each\nnucleotide in the sequence context of a site for it to\nbe included in output file. If the sequence context\nhas three nucleotides, an example of this option is '0\n1 2'. It requires no mismatch basecall at the first\nnucleotide, at most one mismatch basecall at the\nsecond nucleotide, and at most two at the third\nnucleotide for a site to be reported. (default: None)")), ToolOutput(tag="out_max_mismatch_frac", output_type=File(optional=True), selector=InputSelector(input_to_select="in_max_mismatch_frac", type_hint=File()), doc=OutputDocumentation(doc="Maximum fraction of mismatch basecalls out of\nunambiguous basecalls allowed in each nucleotide in\nthe sequence context of a site for it to be included\nin output file. If the sequence context has three\nnucleotides, an example of this option is '0 0 0.1'.\nIt requires no mismatch basecall at the first and\nsecond nucleotide, and at most 10% mismatches out of\nunambiguous basecalls at the third nucleotide for a\nsite to be reported. (default: None)"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Methylpy_Filter_Allc_V0_1_0().translate("wdl", allow_empty_container=True)

